@@ -6,6 +6,8 @@
 #define _slp_imp_hpp_
 
 #include <cstdlib>
+#include <algorithm>
+#include <dlfcn.h>
 #include "timing.hpp"
 
 // SLEvaluator
@@ -21,10 +23,46 @@ SLEvaluatorConcrete<RT>::SLEvaluatorConcrete(
   abort();
 }
 
+template <typename RT>
+SLEvaluatorConcrete<RT>::SLEvaluatorConcrete(
+      M2_string libName,
+      int nInputs,
+      int nOutputs,
+      const MutableMat<SMat<RT> >* empty
+      ): mRing(empty->getMat().ring())
+{
+  std::cerr << "SLEvaluatorConcrete constructor not defined for sparse matrices\n";  
+  abort();
+}
+
+template <typename RT>
+SLEvaluatorConcrete<RT>::SLEvaluatorConcrete
+(M2_string libName,
+ int nInputs,
+ int nOutputs,
+ const MutableMat<DMat<RT> >* empty
+ ): mRing(empty->getMat().ring()), isCompiled(true), nInputs(nInputs), nOutputs(nOutputs), nParams(0), parametersAndInputs(nullptr)
+{
+  slp = NULL;
+  //const char* funname = "evaluate";
+  const char* funnameRR = "_Z8evaluatePKdPd";
+  const char* funnameCC = "_Z8evaluatePKSt7complexIdEPS0_";
+  auto libName_std = string_M2_to_std(libName);
+  const char* lib_name = libName_std.c_str();
+  printf("loading from %s\n", lib_name);
+  void* handle = dlopen(lib_name, RTLD_LAZY | RTLD_GLOBAL);
+  if (handle == NULL) ERROR("can't load library %s", lib_name);
+  compiled_fn = (void (*)(ElementType const*, ElementType*)) dlsym(handle, funnameRR);
+  if (compiled_fn == NULL)
+    compiled_fn = (void (*)(ElementType const*, ElementType*)) dlsym(handle, funnameCC);
+  if (compiled_fn == NULL) 
+    std::cerr << "can't link function " << funnameRR << " or " << funnameCC << " from library " << lib_name << std::endl;
+}
+  
 // copy constructor
 template <typename RT>
 SLEvaluatorConcrete<RT>::SLEvaluatorConcrete(const SLEvaluatorConcrete<RT>& a)
-    : SLEvaluator(a), mRing(a.ring()), values(a.values.size())
+  : SLEvaluator(a), mRing(a.ring()), isCompiled(a.isCompiled), values(a.values.size()), compiled_fn(a.compiled_fn), nInputs(a.nInputs), nOutputs(a.nOutputs), nParams(a.nParams)
 {
   slp = a.slp;
   varsPos = a.varsPos;
@@ -32,22 +70,28 @@ SLEvaluatorConcrete<RT>::SLEvaluatorConcrete(const SLEvaluatorConcrete<RT>& a)
   auto j = a.values.begin();
   for (; i != values.end(); ++i, ++j) ring().init_set(*i, *j);
   // std::cout << "SLEvaluatorConcrete: copy constructor for " << this << std::endl;
+  if (a.parametersAndInputs==nullptr) parametersAndInputs = nullptr; else {
+    parametersAndInputs = new ElementType[nParams+nInputs];
+    std::copy(a.parametersAndInputs,a.parametersAndInputs+nParams, parametersAndInputs);
+  }
 }
 
 template <typename RT>
 SLEvaluatorConcrete<RT>::~SLEvaluatorConcrete()
 {
   // std::cout << "~SLEvaluatorConcrete: " << this << std::endl
-  for (auto& v : values) ring().clear(v);
+  if (isCompiled) {// dlclose???
+    if (parametersAndInputs!=nullptr) delete[] parametersAndInputs;
+  } else for (auto& v : values) ring().clear(v);
 }
 
 template <typename RT>
-SLEvaluatorConcrete<RT>::SLEvaluatorConcrete(
-    SLProgram* SLP,
-    M2_arrayint cPos,
-    M2_arrayint vPos,
-    const MutableMat<DMat<RT> >* consts /* DMat<RT>& DMat_consts */)
-    : mRing(consts->getMat().ring())
+SLEvaluatorConcrete<RT>::SLEvaluatorConcrete
+(SLProgram* SLP,
+ M2_arrayint cPos,
+ M2_arrayint vPos,
+ const MutableMat<DMat<RT> >* consts /* DMat<RT>& DMat_consts */
+ ): mRing(consts->getMat().ring()), isCompiled(false), compiled_fn(NULL), nParams(0), parametersAndInputs(nullptr)
 {
   slp = SLP;
   // for(int i=0; i<cPos->len; i++)
@@ -60,6 +104,8 @@ SLEvaluatorConcrete<RT>::SLEvaluatorConcrete(
     ring().set(values[slp->inputCounter + cPos->array[i]],
                consts->getMat().entry(0, i));
   // std::cout << "SLEvaluatorConcrete(MutableMat): " << this << std::endl;
+  nInputs = varsPos.size();
+  nOutputs = slp->mOutputPositions.size();
 }
 
 template <typename RT>
@@ -77,13 +123,26 @@ template <typename RT>
 SLEvaluator* SLEvaluatorConcrete<RT>::specialize(
     const MutableMat<DMat<RT> >* parameters) const
 {
-  if (parameters->n_cols() != 1 || parameters->n_rows() > varsPos.size()) 
+  size_t nNewParams = parameters->n_rows();  
+  if (parameters->n_cols() != 1 || nNewParams > nInputs) 
     throw exc::engine_error("1-column matrix expected; or #parameters > #vars");
   SLEvaluatorConcrete<RT>* e = new SLEvaluatorConcrete<RT>(*this);
-  size_t nParams = parameters->n_rows();
-  for (int i = 0; i < nParams; ++i)
-    ring().set(e->values[varsPos[i]], parameters->getMat().entry(i, 0));
-  e->varsPos.erase(e->varsPos.begin(), e->varsPos.begin() + nParams);
+  if (isCompiled) {
+    e->nParams = nParams + nNewParams;
+    e->nInputs -= nNewParams;
+    delete[] e->parametersAndInputs;
+    e->parametersAndInputs = new ElementType[e->nParams+e->nInputs];
+    std::copy(parametersAndInputs, parametersAndInputs+nParams, e->parametersAndInputs); // old parameters values
+    for (int i = 0; i < nNewParams; ++i)
+      ring().set(e->parametersAndInputs[nParams+i], parameters->getMat().entry(i, 0));
+  }
+  else {
+    for (int i = 0; i < nNewParams; ++i)
+      ring().set(e->values[varsPos[i]], parameters->getMat().entry(i, 0));
+    e->varsPos.erase(e->varsPos.begin(), e->varsPos.begin() + nNewParams);
+    e->nInputs = e->varsPos.size();
+    e->nParams = nParams + nNewParams;
+  }
   return e;
 }
 
@@ -151,7 +210,6 @@ bool SLEvaluatorConcrete<RT>::evaluate(const MutableMatrix* inputs,
       ERROR("outputs are in a different ring");
       return false;
     }
-
   return evaluate(inp->getMat(), out->getMat());
 }
 
@@ -159,51 +217,67 @@ template <typename RT>
 bool SLEvaluatorConcrete<RT>::evaluate(const DMat<RT>& inputs,
                                        DMat<RT>& outputs)
 {
-  if (varsPos.size() != inputs.numRows() * inputs.numColumns())
-    {
-      ERROR(
+  if (nInputs != inputs.numRows() * inputs.numColumns()) {
+    ERROR(
           "inputs: the number of inputs does not match the number of entries "
           "in the inputs matrix");
-      std::cout << varsPos.size()
-                << " != " << inputs.numRows() * inputs.numColumns()
-                << std::endl;
-      return false;
-    }
-  size_t i = 0;
-  for (size_t r = 0; r < inputs.numRows(); r++)
-    for (size_t c = 0; c < inputs.numColumns(); c++)
-      ring().set(values[varsPos[i++]], inputs.entry(r, c));
-
-  nIt = slp->mNodes.begin();
-  numInputsIt = slp->mNumInputs.begin();
-  inputPositionsIt = slp->mInputPositions.begin();
-  for (vIt = values.begin() + slp->inputCounter; vIt != values.end(); ++vIt)
-    computeNextNode();
-
-  if (slp->mOutputPositions.size() != outputs.numRows() * outputs.numColumns())
-    {
-      ERROR(
+    std::cout << nInputs
+              << " != " << inputs.numRows() * inputs.numColumns()
+              << std::endl;
+    return false;
+  }
+  if (nOutputs != outputs.numRows() * outputs.numColumns()) {
+    ERROR(
           "outputs: the number of outputs does not match the number of entries "
           "in the outputs matrix");
-      std::cout << slp->mOutputPositions.size() << " != " << outputs.numRows()
-                << " * " << outputs.numColumns() << std::endl;
-      return false;
+    std::cout << nOutputs << " != " << outputs.numRows()
+              << " * " << outputs.numColumns() << std::endl;
+    return false;
+  }
+
+  if (isCompiled) {
+    if(parametersAndInputs==nullptr) {
+      (*compiled_fn)(inputs.array(), outputs.array());
+    } else {
+      std::copy(inputs.array(),inputs.array()+nInputs,parametersAndInputs+nParams); 
+      (*compiled_fn)(parametersAndInputs, outputs.array());
     }
-  i = 0;
-  for (size_t r = 0; r < outputs.numRows(); r++)
-    for (size_t c = 0; c < outputs.numColumns(); c++)
-      ring().set(outputs.entry(r, c), values[ap(slp->mOutputPositions[i++])]);
-  return true;
+    return true;
+  } else {                           
+    size_t i = 0;
+    for (size_t r = 0; r < inputs.numRows(); r++)
+      for (size_t c = 0; c < inputs.numColumns(); c++)
+        ring().set(values[varsPos[i++]], inputs.entry(r, c));
+    nIt = slp->mNodes.begin();
+    numInputsIt = slp->mNumInputs.begin();
+    inputPositionsIt = slp->mInputPositions.begin();
+    for (vIt = values.begin() + slp->inputCounter; vIt != values.end(); ++vIt)
+      computeNextNode();
+    i = 0;
+    for (size_t r = 0; r < outputs.numRows(); r++)
+      for (size_t c = 0; c < outputs.numColumns(); c++)
+        ring().set(outputs.entry(r, c), values[ap(slp->mOutputPositions[i++])]);
+    return true;
+  }
 }
 
 template <typename RT>
 void SLEvaluatorConcrete<RT>::text_out(buffer& o) const
 {
-  o << "SLEvaluator(slp = ";
-  slp->text_out(o);
-  o << ", mRing = ";
-  ring().text_out(o);
-  o << ")" << newline;
+  if(isCompiled) {
+    o << "compiled SLEvaluator("
+      << nInputs << " inputs, "
+      << nOutputs << " outputs, "
+      << nParams << " parameters, mRing = ";
+    ring().text_out(o);
+    o << ")" << newline;
+  } else {
+    o << "SLEvaluator(slp = ";
+    slp->text_out(o);
+    o << ", mRing = ";
+    ring().text_out(o);
+    o << ")" << newline;
+  }
 }
 
 template <typename RT>
