@@ -1,6 +1,7 @@
 #ifndef __vector_arithmetic_hpp__
 #define __vector_arithmetic_hpp__
 
+#include "m2tbb.hpp"
 #include "NCAlgebras/Range.hpp"  // for Range
 #include "newdelete.hpp"         // for VECTOR
 #include "MemoryBlock.hpp"       // for MemoryBlock
@@ -8,11 +9,7 @@
 #include "aring-glue.hpp"
 #include <variant>
 #include <type_traits>
-
 #include "f4/f4-mem.hpp"         // for F4Mem
-
-#include <tbb/null_mutex.h>
-
 #include "ARingElem.hpp"
 
 class Ring;
@@ -22,77 +19,49 @@ using ComponentIndex = int;
 // this is still deriving from our_new_delete, since this
 // class doesn't know whether mValue points to a std::vector or a VECTOR.
 // this issue persists in the Row struct in NCF4 as well.
-class CoeffVector : public our_new_delete
+class ElementArray
 {
-  // disallow copy...
- public:
-  CoeffVector() : mValue(nullptr) {}
-  bool isNull() const { return mValue == nullptr; }
-  void swap(CoeffVector& b) { std::swap(mValue, b.mValue); }
-  void* getValue() { return mValue; }
-  void setValue(void* newValue) { mValue = newValue; }
- private:
-  void* mValue;
-};
+  template<typename RingType, typename ElementArrayType> friend class ConcreteVectorArithmetic;
 
-class DenseCoeffVector : public our_new_delete
-{
+public:
+  ElementArray() : mValue(nullptr) {}
+  bool  isNull() const { return mValue == nullptr; }
+  void  swap(ElementArray& b) { std::swap(mValue, b.mValue); }
+
+private:
   // disallow copy...
- public:
-  DenseCoeffVector() : mValue(nullptr) {}
-  bool isNull() const { return mValue == nullptr; }
-  void swap(DenseCoeffVector& b) { std::swap(mValue, b.mValue); }
-  void* getValue() { return mValue; }
-  void setValue(void* newValue) { mValue = newValue; }
- private:
+  ElementArray(void *p) : mValue(p) {} // transfers ownership of this pointer to this object
+
+  //ElementArray(ElementArray &b) { mValue = nullptr; std::swap(mValue,b.mValue); }
+  //ElementArray(const ElementArray && b) : mValue(b.mValue) { b.mValue = nullptr; } 
+  //ElementArray(ElementArray &b) = delete;
+  void* getValue() const { return mValue; }
+  void  setValue(void* newValue) { mValue = newValue; }
+
   void* mValue;
 };
 
 template<typename RingType,
-         typename CoeffVectorType = CoeffVector,
-         typename DenseCoeffVectorType = DenseCoeffVector>
+         typename ElementArrayType = ElementArray>
 class ConcreteVectorArithmetic
 {
 public:
   using FieldElement = typename RingType::ElementType;
-  using DenseFieldElement = FieldElement;
 
-  using CoeffVectorContainer = typename RingType::ElementContainerType;
+  using ElementArrayContainer = typename RingType::ElementContainerType;
   // we may want to change the container type of dense vectors in the future.
-  using DenseCoeffVectorContainer = CoeffVectorContainer;
 
   friend class VectorArithmetic;
 
   ConcreteVectorArithmetic() : mOriginalRing(nullptr), mRing(nullptr) {}
 
-// private:
+ private:
   const Ring* mOriginalRing;
   const RingType* mRing;
 
-  CoeffVectorContainer* coeffVector(CoeffVectorType f) const
+  ElementArrayContainer* elementArray(const ElementArrayType& f) const
   {
-    return reinterpret_cast<CoeffVectorContainer*>(f.getValue());
-  }
-
-  DenseCoeffVectorContainer* denseCoeffVector(DenseCoeffVectorType f) const
-  {
-    return reinterpret_cast<DenseCoeffVectorContainer*>(f.getValue());
-  }
-  
-  CoeffVectorType coeffVector(CoeffVectorContainer* vals) const
-  {
-    CoeffVectorType result;
-    result.setValue(vals);
-    vals = nullptr;
-    return result;
-  }
-
-  DenseCoeffVectorType denseCoeffVector(DenseCoeffVectorContainer* vals) const
-  {
-    DenseCoeffVectorType result;
-    result.setValue(vals);
-    vals = nullptr;
-    return result;
+    return reinterpret_cast<ElementArrayContainer*>(f.getValue());
   }
 
 public:
@@ -103,21 +72,10 @@ public:
   /////////////////////////////
   // Allocation/Deallocation //
   /////////////////////////////
-  CoeffVectorType allocateCoeffVector(ComponentIndex nelems) const
+  ElementArrayType copyElementArray(const ElementArray& sparse) const
   {
-    auto tempPtr = new CoeffVectorContainer(nelems);
-    for (auto& d : *tempPtr)
-      {
-	mRing->init(d);
-	mRing->set_zero(d);
-      }
-    return coeffVector(tempPtr);    
-  }
-
-  CoeffVectorType copyCoeffVector(const CoeffVector& sparse) const
-  {
-    auto& v = * coeffVector(sparse);
-    auto tempPtr = new CoeffVectorContainer(v.size());
+    auto& v = * elementArray(sparse);
+    auto tempPtr = new ElementArrayContainer(v.size());
 
     int n = 0;
     for (auto& d : *tempPtr)
@@ -125,66 +83,49 @@ public:
 	mRing->init_set(d, v[n]);
         ++n;
       }
-    return coeffVector(tempPtr);    
+    return ElementArrayType {tempPtr};    
   }
 
-  DenseCoeffVectorType allocateDenseCoeffVector(ComponentIndex nelems) const
+  ElementArrayType allocateElementArray(ComponentIndex nelems) const
   {
-    auto tempPtr = new DenseCoeffVectorContainer(nelems);
+    auto tempPtr = new ElementArrayContainer(nelems);
     for (auto& d : *tempPtr)
       {
 	mRing->init(d);
 	mRing->set_zero(d);
       }
-    return denseCoeffVector(tempPtr);    
+    return ElementArrayType {tempPtr};    
   }
-  // CoeffVector allocateCoeffVector() const
-  // {
-  //   return coeffVector(new std::vector<FieldElement>);
-  // }
-  void deallocateCoeffVector(CoeffVectorType& coeffs) const
+
+  void deallocateElementArray(ElementArrayType& coeffs) const
   {
-    auto& svec = * coeffVector(coeffs);
+    auto& svec = * elementArray(coeffs);
     for (auto& e : svec) {
       mRing->clear(e);
     }
     delete &svec;
+    coeffs.setValue(nullptr);
   }
 
-  void deallocateCoeffVector(DenseCoeffVectorType& coeffs) const
-  {
-    auto& dvec = * denseCoeffVector(coeffs);
-    for (auto& e : dvec) {
-      mRing->clear(e);
-    }
-    delete &dvec;
-  }
-  
   ////////////////////////
   /// Linear Algebra /////
   ////////////////////////
 
-  size_t size(const CoeffVectorType& coeffs) const
+  size_t size(const ElementArrayType& coeffs) const
   {
-    return coeffVector(coeffs)->size();
+    return elementArray(coeffs)->size();
   }
 
-  size_t size(const DenseCoeffVectorType& coeffs) const
-  {
-    return denseCoeffVector(coeffs)->size();
-  }
-  
-  // better name: fillDenseRow.
-  void sparseRowToDenseRow(DenseCoeffVectorType& dense,
-                           const CoeffVectorType& sparse,
-                           const Range<int>& comps) const
+  void fillDenseArray(ElementArrayType& dense,
+                      const ElementArrayType& sparse,
+                      const Range<int>& comps) const
   {
     // Note: this function simply fills in the values coming from '(sparse, comps)'.
     //   Other values are not touched.
     // In our intended uses, the input `dense` is the vector consisting of all zeros.
     
-    auto& dvec = * denseCoeffVector(dense);
-    auto& svec = * coeffVector(sparse);
+    auto& dvec = * elementArray(dense);
+    auto& svec = * elementArray(sparse);
     
     assert(comps.size() == svec.size());
     assert(comps[comps.size()-1] < dvec.size());
@@ -193,24 +134,24 @@ public:
     for (ComponentIndex i = 0; i < len; i++) mRing->set(dvec[comps[i]],svec[i]);
   }
 
-  void denseRowCancelFromSparse(DenseCoeffVectorType& dense,
-                                const CoeffVectorType& sparse,
-                                const Range<int>& comps) const
+  void denseCancelFromSparse(ElementArrayType& dense,
+                             const ElementArrayType& sparse,
+                             const Range<int>& comps) const
   {
     // ASSUMPTION: svec[0] == 1.
-    auto& dvec = * denseCoeffVector(dense);
-    auto& svec = * coeffVector(sparse);
+    auto& dvec = * elementArray(dense);
+    auto& svec = * elementArray(sparse);
 
     ARingElem a(mRing,dvec[comps[0]]);
     for (int i=0; i < comps.size(); ++i)
       mRing->subtract_multiple(dvec[comps[i]], *a, svec[i]);
   }
 
-  int denseRowNextNonzero(DenseCoeffVectorType& dense,
-                          int first,
-                          int last) const
+  int denseNextNonzero(ElementArrayType& dense,
+                       int first,
+                       int last) const
   {
-    auto& dvec = * denseCoeffVector(dense);
+    auto& dvec = * elementArray(dense);
     for (int i = first; i <= last; i++)
       {
 	if (mRing->is_zero(dvec[i])) continue;
@@ -223,15 +164,15 @@ public:
     return last + 1;
   }
 
-  void denseRowToSparseRow(DenseCoeffVectorType& dense,
-                           CoeffVectorType& sparse, // output value: sets this value
-                           Range<int>& comps, // output value: sets comps
-                           int first,
-                           int last,
-                           MemoryBlock& monomialSpace) const
+  void denseToSparse(ElementArrayType& dense,
+                     ElementArrayType& sparse, // output value: sets this value
+                     Range<int>& comps, // output value: sets comps
+                     int first,
+                     int last,
+                     MemoryBlock& monomialSpace) const
   { 
-    tbb::null_mutex noLock;
-    safeDenseRowToSparseRow<tbb::null_mutex>(dense,
+    mtbb::null_mutex noLock;
+    safeDenseToSparse<mtbb::null_mutex>(dense,
 					     sparse,
 					     comps,
 					     first,
@@ -241,15 +182,15 @@ public:
   }
 
   template<typename LockType>
-  void safeDenseRowToSparseRow(DenseCoeffVectorType& dense,
-                               CoeffVectorType& sparse, // output value: sets this value
+  void safeDenseToSparse(ElementArrayType& dense,
+                               ElementArrayType& sparse, // output value: sets this value
                                Range<int>& comps, // output value: sets comps
                                int first,
                                int last,
                                MemoryBlock& monomialSpace,
                                LockType& lock) const
   {
-    auto& dvec = * denseCoeffVector(dense);
+    auto& dvec = * elementArray(dense);
     
     int len = 0;
     
@@ -259,9 +200,9 @@ public:
 	if (not mRing->is_zero(dvec[i])) len++;
 
     comps = monomialSpace.safeAllocateArray<int,LockType>(len,lock);
-    deallocateCoeffVector(sparse);
-    sparse = allocateCoeffVector(len);
-    auto& svec = * coeffVector(sparse);
+    deallocateElementArray(sparse);
+    sparse = allocateElementArray(len);
+    auto& svec = * elementArray(sparse);
 
     int next = 0;
     for (int i = first; i >= 0 and i <= last; i++)
@@ -274,14 +215,14 @@ public:
 	}
   }
 
-  void denseRowToSparseRow(DenseCoeffVectorType& dense,
-                           CoeffVectorType& sparse, // output value: sets this value
+  void denseToSparse(ElementArrayType& dense,
+                           ElementArrayType& sparse, // output value: sets this value
                            int*& comps,
                            int first,
                            int last,
                            F4Vec& f4Vec) const
   {
-    auto& dvec = * denseCoeffVector(dense);
+    auto& dvec = * elementArray(dense);
     
     int len = 0;
     
@@ -292,8 +233,8 @@ public:
 
     comps = f4Vec.allocate(len);
 
-    sparse = allocateCoeffVector(len);
-    auto& svec = * coeffVector(sparse);
+    sparse = allocateElementArray(len);
+    auto& svec = * elementArray(sparse);
 
     int next = 0;
     for (int i = first; i >= 0 and i <= last; i++)
@@ -306,11 +247,11 @@ public:
 	}
   }
 
-  void setZeroInRange(DenseCoeffVectorType& dense,
+  void setZeroInRange(ElementArrayType& dense,
                       int first,
                       int last) const
   {
-    auto& dvec = * denseCoeffVector(dense);
+    auto& dvec = * elementArray(dense);
     
     // first can be -1 if the row is zero.  in this case, we should
     // not be accessing dvec[i] for i negative.
@@ -318,9 +259,9 @@ public:
       mRing->set_zero(dvec[i]);
   }
   
-  void sparseRowMakeMonic(CoeffVectorType& sparse) const
+  void makeMonic(ElementArrayType& sparse) const
   {
-    auto& svec = * coeffVector(sparse);
+    auto& svec = * elementArray(sparse);
 
     ARingElem leadCoeffInv(mRing);
 
@@ -330,10 +271,10 @@ public:
   }
 
   template<typename Container>
-  void appendSparseVectorToContainer(const CoeffVectorType& sparse,
-                                     Container& c) const
+  void appendToContainer(const ElementArrayType& sparse,
+                         Container& c) const
   {
-    auto& svec = * coeffVector(sparse);
+    auto& svec = * elementArray(sparse);
     for (const auto& a : svec)
       {
 	ring_elem tmp;
@@ -343,10 +284,10 @@ public:
   }
 
   template<typename Container>
-  CoeffVectorType sparseVectorFromContainer(const Container& c) const
+  ElementArrayType elementArrayFromContainer(const Container& c) const
   {
-    CoeffVectorType sparse = allocateCoeffVector(c.size());
-    auto& svec = * coeffVector(sparse);
+    ElementArrayType sparse = allocateElementArray(c.size());
+    auto& svec = * elementArray(sparse);
     for (auto i = 0; i < c.size(); ++i)
     {
       mRing->init(svec[i]);
@@ -355,18 +296,18 @@ public:
     return sparse;
   }
 
-  ring_elem ringElemFromSparseVector(const CoeffVectorType& sparse,
+  ring_elem ringElemFromElementArray(const ElementArrayType& sparse,
                                      int index) const
   {
-    auto& svec = * coeffVector(sparse);
+    auto& svec = * elementArray(sparse);
     ring_elem tmp;
     mRing->to_ring_elem(tmp,svec[index]);
     return tmp;
   }
 
-  std::ostream& displayVector(std::ostream& o, const CoeffVectorType& v) const
+  std::ostream& displayElementArray(std::ostream& o, const ElementArrayType& v) const
   {
-    auto& svec = * coeffVector(v);
+    auto& svec = * elementArray(v);
 
     bool first = true;
     o << "[(" << svec.size() << ")";
@@ -388,40 +329,42 @@ public:
   /// Append support /////
   ////////////////////////
   
-  void pushBackOne(CoeffVectorType& coeffs) const
+  void pushBackOne(ElementArrayType& coeffs) const
   {
-    auto& svec = * coeffVector(coeffs);
+    auto& svec = * elementArray(coeffs);
     FieldElement one;
-    mRing->init_set(one, 1);
+    mRing->init(one);
+    mRing->set_from_long(one, 1);
     svec.emplace_back(one); // This grabs 'one' in cases where it is allocated...  I think...!
   }
 
-  void pushBackMinusOne(CoeffVectorType& coeffs) const
+  void pushBackMinusOne(ElementArrayType& coeffs) const
   {
-    auto& svec = * coeffVector(coeffs);
+    auto& svec = * elementArray(coeffs);
     FieldElement minus_one;
-    mRing->init_set(minus_one, -1);
+    mRing->init(minus_one);
+    mRing->set_from_long(minus_one,-1);
     svec.emplace_back(minus_one);
   }
 
-  void pushBackElement(CoeffVectorType& coeffs,
-                       const CoeffVectorType& take_from_here,
+  void pushBackElement(ElementArrayType& coeffs,
+                       const ElementArrayType& take_from_here,
                        size_t loc) const
   {
-    auto& svec = * coeffVector(coeffs);
-    auto& svec2 = * coeffVector(take_from_here);
+    auto& svec = * elementArray(coeffs);
+    auto& svec2 = * elementArray(take_from_here);
     assert(loc < svec2.size());
     FieldElement a;
     mRing->init_set(a, svec2[loc]);
     svec.emplace_back(a);
   }
   
-  void pushBackNegatedElement(CoeffVectorType& coeffs,
-                              const CoeffVectorType& take_from_here,
+  void pushBackNegatedElement(ElementArrayType& coeffs,
+                              const ElementArrayType& take_from_here,
                               size_t loc) const
   {
-    auto& svec = * coeffVector(coeffs);
-    auto& svec2 = * coeffVector(take_from_here);
+    auto& svec = * elementArray(coeffs);
+    auto& svec2 = * elementArray(take_from_here);
     assert(loc < svec2.size());
     FieldElement a;
     mRing->init_set(a, svec2[loc]);
@@ -439,8 +382,7 @@ template<class... Ts> overloaded(Ts...) -> overloaded<Ts...>;
 // this is the dispatching class using std::variant
 class VectorArithmetic
 {
-  using CoeffVectorType = CoeffVector;
-  using DenseCoeffVectorType = DenseCoeffVector;
+  using ElementArrayType = ElementArray;
 
   // does the order of the variant types matter?
   using CVA_Type = std::variant<ConcreteVectorArithmetic<M2::ARingZZpFlint>*,
@@ -524,100 +466,88 @@ public:
   }
 
   // provide simple visitor interface to underlying std::variant types
-  size_t size(const CoeffVectorType& coeffs) const {
+  size_t size(const ElementArrayType& coeffs) const {
     return std::visit([&](auto& arg) -> size_t { return arg->size(coeffs); }, mConcreteVector);
   }
   
-  size_t size(const DenseCoeffVectorType& coeffs) const {
-    return std::visit([&](auto& arg) -> size_t { return arg->size(coeffs); }, mConcreteVector);
-  }
-
   /////////////////////////////
   // Allocation/Deallocation //
   /////////////////////////////
   /// Create a coefficient vector with room for `nelems` coefficients
-  CoeffVectorType allocateCoeffVector(ComponentIndex nelems) const {
-    return std::visit([&](auto& arg) -> CoeffVectorType { return arg->allocateCoeffVector(nelems);}, mConcreteVector);
+  ElementArrayType allocateElementArray(ComponentIndex nelems) const {
+    return std::visit([&](auto& arg) -> ElementArrayType { return arg->allocateElementArray(nelems);}, mConcreteVector);
   }
 
-  CoeffVectorType copyCoeffVector(const CoeffVector& sparse) const {
-    return std::visit([&](auto& arg) -> CoeffVectorType { return arg->copyCoeffVector(sparse);}, mConcreteVector);
-  }
-
-  DenseCoeffVectorType allocateDenseCoeffVector(ComponentIndex nelems) const {
-    return std::visit([&](auto& arg) -> DenseCoeffVectorType { return arg->allocateDenseCoeffVector(nelems);}, mConcreteVector);
+  ElementArrayType copyElementArray(const ElementArray& sparse) const {
+    return std::visit([&](auto& arg) -> ElementArrayType { return arg->copyElementArray(sparse);}, mConcreteVector);
   }
 
   /// Create a coefficient vector with 0 elements.  Can be increased in size.
-  // CoeffVectorType allocateCoeffVector() const = 0;
+  // ElementArrayType allocateElementArray() const = 0;
 
   /// Deallocate all the coefficients, and the array itself.
-  void deallocateCoeffVector(CoeffVectorType& coeffs) const {
-    std::visit([&](auto& arg) { arg->deallocateCoeffVector(coeffs); }, mConcreteVector);
+  void deallocateElementArray(ElementArrayType& coeffs) const {
+    std::visit([&](auto& arg) { arg->deallocateElementArray(coeffs); }, mConcreteVector);
   }
   
-  void deallocateCoeffVector(DenseCoeffVectorType& coeffs) const {
-    std::visit([&](auto& arg) { arg->deallocateCoeffVector(coeffs); }, mConcreteVector);
-  }
-
   ////////////////////////
   /// Linear Algebra /////
   ////////////////////////
-  void sparseRowToDenseRow(DenseCoeffVectorType& dense,
-			   const CoeffVectorType& coeffs,
+  void fillDenseArray(ElementArrayType& dense,
+			   const ElementArrayType& coeffs,
 			   const Range<int>& comps) const {
-    std::visit([&](auto& arg) { arg->sparseRowToDenseRow(dense,coeffs,comps); }, mConcreteVector);
+    std::visit([&](auto& arg) { arg->fillDenseArray(dense,coeffs,comps); }, mConcreteVector);
   }
 
-  void denseRowCancelFromSparse(DenseCoeffVectorType& dense,
-                                const CoeffVectorType& coeffs,
+  void denseCancelFromSparse(ElementArrayType& dense,
+                                const ElementArrayType& coeffs,
                                 const Range<int>& comps) const {
-    std::visit([&](auto& arg) { arg->denseRowCancelFromSparse(dense,coeffs,comps); }, mConcreteVector);
+    std::visit([&](auto& arg) { arg->denseCancelFromSparse(dense,coeffs,comps); }, mConcreteVector);
   }
 
-  int denseRowNextNonzero(DenseCoeffVectorType& dense,
+  int denseNextNonzero(ElementArrayType& dense,
                           int first,
                           int last) const {
-    return std::visit([&](auto& arg) -> int { return arg->denseRowNextNonzero(dense,first,last); }, mConcreteVector);
+    return std::visit([&](auto& arg) -> int { return arg->denseNextNonzero(dense,first,last); }, mConcreteVector);
   }
 
-  void denseRowToSparseRow(DenseCoeffVectorType& dense,
-                           CoeffVectorType& coeffs, // sets coeffs
+  void denseToSparse(ElementArrayType& dense,
+                           ElementArrayType& coeffs, // sets coeffs
                            Range<int>& comps, // sets comps
                            int first,
                            int last,
                            MemoryBlock& monomialSpace) const {
-    std::visit([&](auto& arg) { arg->denseRowToSparseRow(dense,coeffs,comps,first,last,monomialSpace); }, mConcreteVector);  
+    std::visit([&](auto& arg) { arg->denseToSparse(dense,coeffs,comps,first,last,monomialSpace); }, mConcreteVector);  
   }
 
-  void denseRowToSparseRow(DenseCoeffVectorType& dense,
-                           CoeffVectorType& coeffs, // sets coeffs
+  void denseToSparse(ElementArrayType& dense,
+                           ElementArrayType& coeffs, // sets coeffs
                            int*& comps, // sets comps
                            int first,
                            int last,
                            F4Vec& f4Vec) const {
-    std::visit([&](auto& arg) { arg->denseRowToSparseRow(dense,coeffs,comps,first,last,f4Vec); }, mConcreteVector);  
+    std::visit([&](auto& arg) { arg->denseToSparse(dense,coeffs,comps,first,last,f4Vec); }, mConcreteVector);  
   }
 
   template<typename LockType>
-  void safeDenseRowToSparseRow(DenseCoeffVectorType& dense,
-                               CoeffVectorType& coeffs, // sets coeffs
+  void safeDenseToSparse(ElementArrayType& dense,
+                               ElementArrayType& coeffs, // sets coeffs
                                Range<int>& comps, // sets comps
                                int first,
                                int last,
                                MemoryBlock& monomialSpace,
                                LockType& lock) const {
     // the existence of 'template' here is a bit jarring to me, but it tells the compiler
-    // that safeDenseRowToSparseRow is a template function
-    std::visit([&](auto& arg) { arg->template safeDenseRowToSparseRow<LockType>(dense,coeffs,comps,first,last,monomialSpace,lock); }, mConcreteVector);      
+    // that safeDenseToSparse is a template function
+    std::visit([&](auto& arg) { arg->template safeDenseToSparse<LockType>(dense,coeffs,comps,first,last,monomialSpace,lock); }, mConcreteVector);      
   }
 
-  void setZeroInRange(DenseCoeffVectorType& dense, int first, int last) const {
+  void setZeroInRange(ElementArrayType& dense, int first, int last) const {
     std::visit([&](auto& arg) { arg->setZeroInRange(dense, first, last); }, mConcreteVector);      
   }
   
-  void sparseRowMakeMonic(CoeffVectorType& coeffs) const {
-    std::visit([&](auto& arg) { arg->sparseRowMakeMonic(coeffs); }, mConcreteVector);      
+  void makeMonic(ElementArrayType& coeffs) const {
+    std::visit([&](auto& arg) { arg->makeMonic(coeffs); }, mConcreteVector);      
   }
 
   /////////////////////////////
@@ -625,30 +555,54 @@ public:
   /////////////////////////////
 
   template<class Container>
-  void appendSparseVectorToContainer(const CoeffVectorType& coeffs,
+  void appendToContainer(const ElementArrayType& coeffs,
                                      Container& c) const {
-    std::visit([&](auto& arg) { arg->template appendSparseVectorToContainer<Container>(coeffs, c); }, mConcreteVector);      
+    std::visit([&](auto& arg) { arg->template appendToContainer<Container>(coeffs, c); }, mConcreteVector);      
   }
 
   template<class Container>
-  CoeffVectorType sparseVectorFromContainer(const Container& c) const {
-    return std::visit([&](auto& arg) -> CoeffVectorType { return arg->template sparseVectorFromContainer<Container>(c); }, mConcreteVector);
+  ElementArrayType elementArrayFromContainer(const Container& c) const {
+    return std::visit([&](auto& arg) -> ElementArrayType { return arg->template elementArrayFromContainer<Container>(c); }, mConcreteVector);
   }
 
-  ring_elem ringElemFromSparseVector(const CoeffVectorType& coeffs,
+  ring_elem ringElemFromElementArray(const ElementArrayType& coeffs,
                                      int index) const {
-    return std::visit([&](auto& arg) -> ring_elem { return arg->ringElemFromSparseVector(coeffs,index); }, mConcreteVector);
+    return std::visit([&](auto& arg) -> ring_elem { return arg->ringElemFromElementArray(coeffs,index); }, mConcreteVector);
   }
 
-  std::ostream& displayVector(std::ostream& o, const CoeffVectorType& v) const
+  std::ostream& displayElementArray(std::ostream& o, const ElementArrayType& v) const
   {
-    return std::visit([&](auto& arg) -> std::ostream& { return arg->displayVector(o, v); }, mConcreteVector);
+    return std::visit([&](auto& arg) -> std::ostream& { return arg->displayElementArray(o, v); }, mConcreteVector);
   }
 
   //////////////////////////
   /// Append support   /////
   //////////////////////////
-  // TODO
+  
+  void pushBackOne(ElementArrayType& coeffs) const
+  {
+    return std::visit([&](auto& arg) { arg->pushBackOne(coeffs); }, mConcreteVector);
+  }
+
+  void pushBackMinusOne(ElementArrayType& coeffs) const
+  {
+    return std::visit([&](auto& arg) { arg->pushBackMinusOne(coeffs); }, mConcreteVector);
+  }
+
+  void pushBackElement(ElementArrayType& coeffs,
+                       const ElementArrayType& take_from_here,
+                       size_t loc) const
+  {
+    return std::visit([&](auto& arg) { arg->pushBackElement(coeffs,take_from_here,loc); }, mConcreteVector);
+  }
+  
+  void pushBackNegatedElement(ElementArrayType& coeffs,
+                              const ElementArrayType& take_from_here,
+                              size_t loc) const
+  {
+    return std::visit([&](auto& arg) { arg->pushBackNegatedElement(coeffs,take_from_here,loc); }, mConcreteVector);
+  }
+
 };
 
 #endif
