@@ -79,7 +79,7 @@ class DMat
   typedef DMatIterator<ACoeffRing> Iterator;
   typedef DMatConstIterator<ACoeffRing> ConstIterator;
 
-  DMat() : mRing(0), mNumRows(0), mNumColumns(0), mArray(nullptr) {}
+  DMat() : mRing(nullptr), mNumRows(0), mNumColumns(0), mArray(nullptr) {}
   DMat(const ACoeffRing& R, size_t nrows, size_t ncols)
       : mRing(&R), mNumRows(nrows), mNumColumns(ncols)
   {
@@ -116,7 +116,7 @@ class DMat
     size_t len = mNumRows * mNumColumns;
     for (size_t i = 0; i < len; i++) ring().clear(mArray[i]);
     //    if (mArray != 0) delete[] mArray;
-    if (mArray != nullptr) GC_FREE(mArray);
+    if (mArray != nullptr) freemem(mArray);
   }
 
   // swap the actual matrices of 'this' and 'M'.
