@@ -243,7 +243,7 @@ void F4MonomialLookupTableT<Key>::update_exponent_vector(
   if (size_of_exp <= nvars)
     {
       // Increase size of exponent vector
-      deleteitem(exp0);
+      freemem(exp0);
       if (nvars > 2 * size_of_exp)
         size_of_exp = nvars;
       else
@@ -562,7 +562,7 @@ void minimalize_varpower_monomials(const VECTOR(varpower_monomial) & elems,
                 result_minimals.push_back(*j);
               }
           }
-        deleteitem(bins[i]);
+        freemem(bins[i]);
       }
 }
 
