@@ -1,6 +1,6 @@
 // Copyright 1997-2006 Michael E. Stillman
 
-#include "ntuple-monomial.hpp"
+#include "f4/ntuple-monomial.hpp"
 #include "buffer.hpp"
 
 void ntuple_monomials::elem_text_out(buffer &o,
