@@ -1,16 +1,16 @@
 // Copyright 1995 Michael E. Stillman
 
 #ifndef _ring_hh_
-#define _ring_hh_
+#  define _ring_hh_
 
-#include <utility>           // for pair
+#  include <utility>  // for pair
 
-#include "aring.hpp"         // for RingID, ring_old
-#include "error.h"           // for ERROR
-#include "exceptions.hpp"    // for engine_error
-#include "hash.hpp"          // for MutableEngineObject
-#include "newdelete.hpp"     // for our_new_delete
-#include "ringelem.hpp"      // for ring_elem, vec, vecterm (ptr only), Nter...
+#  include "aring.hpp"       // for RingID, ring_old
+#  include "error.h"         // for ERROR
+#  include "exceptions.hpp"  // for engine_error
+#  include "hash.hpp"        // for MutableEngineObject
+#  include "newdelete.hpp"   // for our_new_delete
+#  include "ringelem.hpp"    // for ring_elem, vec, vecterm (ptr only), Nter...
 
 class ARing;
 class CCC;
@@ -96,18 +96,19 @@ class Ring : public MutableEngineObject
                        const PolynomialRing *DR = 0,
                        const M2_arrayint heft_vec = 0);
   Ring()
-    : mCharacteristic(0),
-      degree_ring(nullptr),
-      heft_vector(nullptr),
-      AR(nullptr),
-      cR(nullptr),
-      _non_unit(),
-      _isfield(0),
-      zeroV(),
-      oneV(),
-      minus_oneV()
+      : mCharacteristic(0),
+        degree_ring(nullptr),
+        heft_vector(nullptr),
+        AR(nullptr),
+        cR(nullptr),
+        _non_unit(),
+        _isfield(0),
+        zeroV(),
+        oneV(),
+        minus_oneV()
   {
   }
+
  public:
   virtual ~Ring();
 
@@ -219,11 +220,23 @@ class Ring : public MutableEngineObject
 
   virtual const M2FreeAlgebra *cast_to_M2FreeAlgebra() const { return nullptr; }
   virtual M2FreeAlgebra *cast_to_M2FreeAlgebra() { return nullptr; }
-  virtual const M2FreeAlgebraQuotient *cast_to_M2FreeAlgebraQuotient() const { return nullptr; }
-  virtual M2FreeAlgebraQuotient *cast_to_M2FreeAlgebraQuotient() { return nullptr; }
-  virtual const M2FreeAlgebraOrQuotient *cast_to_M2FreeAlgebraOrQuotient() const { return nullptr; }
-  virtual M2FreeAlgebraOrQuotient *cast_to_M2FreeAlgebraOrQuotient() { return nullptr; }
-  
+  virtual const M2FreeAlgebraQuotient *cast_to_M2FreeAlgebraQuotient() const
+  {
+    return nullptr;
+  }
+  virtual M2FreeAlgebraQuotient *cast_to_M2FreeAlgebraQuotient()
+  {
+    return nullptr;
+  }
+  virtual const M2FreeAlgebraOrQuotient *cast_to_M2FreeAlgebraOrQuotient() const
+  {
+    return nullptr;
+  }
+  virtual M2FreeAlgebraOrQuotient *cast_to_M2FreeAlgebraOrQuotient()
+  {
+    return nullptr;
+  }
+
   virtual const SchurRing *cast_to_SchurRing() const { return 0; }
   virtual SchurRing *cast_to_SchurRing() { return 0; }
   virtual const SchurRing2 *cast_to_SchurRing2() const { return 0; }
@@ -364,8 +377,8 @@ class Ring : public MutableEngineObject
   virtual void remove(ring_elem &f) const = 0;
 
   void negate_to(ring_elem &f) const;
-  void add_to(ring_elem &f, ring_elem &g) const;
-  void subtract_to(ring_elem &f, ring_elem &g) const;
+  void add_to(ring_elem &f, const ring_elem &g) const;
+  void subtract_to(ring_elem &f, const ring_elem &g) const;
   void mult_to(ring_elem &f, const ring_elem g) const;
   virtual ring_elem negate(const ring_elem f) const = 0;
   virtual ring_elem add(const ring_elem f, const ring_elem g) const = 0;
@@ -598,9 +611,9 @@ class SumCollector : public our_new_delete
   virtual ring_elem getValue() = 0;
 };
 
-#define ZERO_RINGELEM (ring_elem(static_cast<Nterm *>(0)))
+#  define ZERO_RINGELEM (ring_elem(static_cast<Nterm *>(0)))
 
-#include "ZZ.hpp"
+#  include "ZZ.hpp"
 extern RingZZ *globalZZ;
 extern RingZZ *makeIntegerRing();
 
