@@ -399,7 +399,7 @@ M2_arrayint SchreyerFrame::getBetti(int type)
   if (type == 0 or type == 1) return getBettiFrame();
   if (type == 5) return mComputationStatus.getBetti();
 
-  ERROR("betti display not implemenented yet");
+  ERROR("betti display not implemented yet");
   return 0;
 }
 
