@@ -49,8 +49,25 @@ bool WeylAlgebra::initialize_weyl(M2_arrayint derivs,
 
   // Now set whether this ring is graded.  This will be the case iff
   // deg(x_i) + deg(D_i) = 2 deg(h), for every i.
+
   if (_homog_var < 0)
-    this->setIsGraded(false);
+    {
+      bool isgraded = true;
+      const Monoid *D = degree_monoid();
+      int *degxD = D->make_one();
+      for (int j = 0; j < _nderivatives; j++)
+        {
+          const int *degx = M_->degree_of_var(_commutative[j]);
+          const int *degD = M_->degree_of_var(_derivative[j]);
+          D->mult(degx, degD, degxD);
+          if (not D->is_one(degxD))
+            {
+              isgraded = false;
+              break;
+            }
+        }
+      this->setIsGraded(isgraded);
+    }
   else
     {
       this->setIsGraded(true);
